4.10. umbra.components.factory.componentsManagerUi.componentsManagerUi — Umbra 1.0.9 documentation

# 4.10. umbra.components.factory.componentsManagerUi.componentsManagerUi

componentsManagerUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `ComponentsManagerUi` Component Interface class.

Others:

## 4.10.1. Module Attributes

`umbra.components.factory.componentsManagerUi.componentsManagerUi.` `LOGGER`

`umbra.components.factory.componentsManagerUi.componentsManagerUi.` `COMPONENT_UI_FILE`

## 4.10.2. Classes

class `umbra.components.factory.componentsManagerUi.componentsManagerUi.` `ComponentsManagerUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `umbra.components.factory.componentsManagerUi.componentsManagerUi` Component Interface class.
  It defines methods to interact with the `manager.componentsManager.Manager` class Application instance Components.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `refreshNodes`

    This signal is emited by the `ComponentsManagerUi` class when `ComponentsManagerUi.model` class property model Nodes nodes needs to be refreshed. ( pyqtSignal )

  `activatedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is activated. ( pyqtSignal )

    Returns: | Activated Component name.
    Return type: | unicode

  `deactivatedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is deactivated. ( pyqtSignal )

    Returns: | Deactivated Component name.
    Return type: | unicode

  `reloadedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is reloaded. ( pyqtSignal )

    Returns: | Reloaded Component name.
    Return type: | unicode

  `uiResourcesDirectory`

    Property for self.__uiResourcesDirectory attribute.

    Returns: | self.__uiResourcesDirectory.
    Return type: | unicode

  `uiActivatedImage`

    Property for self.__uiActivatedImage attribute.

    Returns: | self.__uiActivatedImage.
    Return type: | unicode

  `uiDeactivatedImage`

    Property for self.__uiDeactivatedImage attribute.

    Returns: | self.__uiDeactivatedImage.
    Return type: | unicode

  `uiCategoryAffixe`

    Property for self.__uiCategoryAffixe attribute.

    Returns: | self.__uiCategoryAffixe.
    Return type: | unicode

  `dockArea`

    Property for self.__dockArea attribute.

    Returns: | self.__dockArea.
    Return type: | int

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `model`

    Property for self.__model attribute.

    Returns: | self.__model.
    Return type: | ComponentsModel

  `view`

    Property for self.__view attribute.

    Returns: | self.__view.
    Return type: | QWidget

  `headers`

    Property for self.__headers attribute.

    Returns: | self.__headers.
    Return type: | list

  `treeViewInnerMargins`

    Property for self.__treeViewInnerMargins attribute.

    Returns: | self.__treeViewInnerMargins.
    Return type: | int

  `componentsInformationsDefaultText`

    Property for self.__componentsInformationsDefaultText attribute.

    Returns: | self.__componentsInformationsDefaultText.
    Return type: | unicode

  `componentsInformationsText`

    Property for self.__componentsInformationsText attribute.

    Returns: | self.__componentsInformationsText.
    Return type: | unicode

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

  `onStartup`()

    Defines the slot triggered by Framework startup.

    Returns: | Method success.
    Return type: | bool

  `activateComponentsUi`()

    Activates user selected Components.

    Returns: | Method success.
    Return type: | bool
    Note: | May require user interaction.

  `deactivateComponentsUi`()

    Deactivates user selected Components.

    Returns: | Method success.
    Return type: | bool
    Note: | May require user interaction.

  `reloadComponentsUi`()

    Reloads user selected Components.

    Returns: | Method success.
    Return type: | bool
    Note: | May require user interaction.

  `activateComponent`(name)

    Activates given Component.

    Parameters: | name (unicode) – Component name.
    Returns: | Method success.
    Return type: | bool

  `deactivateComponent`(name)

    Deactivates given Component.

    Parameters: | name (unicode) – Component name.
    Returns: | Method success.
    Return type: | bool

  `reloadComponent`(name)

    Reloads given Component.

    Parameters: | name (unicode) – Component name.
    Returns: | Method success.
    Return type: | bool

  `getComponents`()

    Returns the Components.

    Returns: | Components.
    Return type: | list

  `listComponents`()

    Lists the Components names.

    Returns: | Components names.
    Return type: | list

  `setComponents`()

    Sets the Components Model nodes.

  `getSelectedNodes`()

    Returns the View selected nodes.

    Returns: | View selected nodes.
    Return type: | dict

  `getSelectedComponentsNodes`()

    Returns the View selected Components nodes.

    Returns: | View selected Components nodes.
    Return type: | list

  `getSelectedComponents`()

    Returns the View selected Components.

    Returns: | View selected Components.
    Return type: | list